@@ -17,13 +17,11 @@
 //# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef CASA_ARRAYOPSDIFFSHAPES_2_H
 #define CASA_ARRAYOPSDIFFSHAPES_2_H
@@ -83,8 +81,8 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 // Returns a LogicalArray with elements (at pos) set to (data(pos) ==
 // truthvalue).  data is effectively collapsed using anyEQ if necessary to
 // fit desiredform.  Throws an exception if that does not work.
-template<typename T, typename Alloc>
-LogicalArray reformedMask(const Array<T, Alloc>& data, const T truthvalue,
+template<typename T>
+LogicalArray reformedMask(const Array<T>& data, const T truthvalue,
 			  const IPosition& desiredform);
 
 // Can arrays left and right with respective shapes leftShape and rightShape be
@@ -104,8 +102,8 @@ bool rightExpandableToLeft(const IPosition& leftShape, const IPosition& rightSha
 //# 			BinaryOperator op);
 
 // Like binOpExpandR(left, right, res, op), but work on left in place.
-template<typename L, typename AllocL, typename R, typename AllocR, typename BinaryOperator>
-void binOpExpandInPlace(Array<L, AllocL>& left, const Array<R, AllocR>& right, BinaryOperator op);
+template<typename L, typename R, typename BinaryOperator>
+void binOpExpandInPlace(Array<L>& left, const Array<R>& right, BinaryOperator op);
 
 // </group>
 
