@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id: Array.h 21545 2015-01-22 19:36:35Z gervandiepen $
 
 //# Includes
 #include "Array.h"
@@ -32,14 +30,14 @@
 
 //# Instantiate extern templates for often used types.
 namespace casacore {
-  template class Array<bool, std::allocator<bool>>;
-  template class Array<char, std::allocator<char>>;
-  template class Array<unsigned char, std::allocator<unsigned char>>;
-  template class Array<short, std::allocator<short>>;
-  template class Array<unsigned short, std::allocator<unsigned short>>;
-  template class Array<int, std::allocator<int>>;
-  template class Array<unsigned int, std::allocator<unsigned int>>;
-  template class Array<long long, std::allocator<long long>>;
-  template class Array<float, std::allocator<float>>;
-  template class Array<double, std::allocator<double>>;
+  template class Array<bool>;
+  template class Array<char>;
+  template class Array<unsigned char>;
+  template class Array<short>;
+  template class Array<unsigned short>;
+  template class Array<int>;
+  template class Array<unsigned int>;
+  template class Array<long long>;
+  template class Array<float>;
+  template class Array<double>;
 }
