@@ -17,20 +17,18 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef CASA_MASKARRIO_2_H
 #define CASA_MASKARRIO_2_H
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
-template<typename T, typename ArrayAlloc, typename MaskAlloc>
+template<typename T>
 class MaskedArray;
 
 // <summary>
@@ -86,13 +84,13 @@ class MaskedArray;
 // 
 // Write out an ascii representation of a MaskedArray.
 // The component Array and LogicalArray are written out sequentially.
-template<typename T, typename ArrayAlloc, typename MaskAlloc>
-std::ostream & operator<< (std::ostream &, const MaskedArray<T, ArrayAlloc, MaskAlloc> &);
+template<typename T>
+std::ostream & operator<< (std::ostream &, const MaskedArray<T> &);
 
 
 // </group>
-template<typename T, typename ArrayAlloc, typename MaskAlloc>
-std::string to_string(const MaskedArray<T, ArrayAlloc, MaskAlloc> &);
+template<typename T>
+std::string to_string(const MaskedArray<T> &);
 
 } //# NAMESPACE CASACORE - END
 
