@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef CASA_MATRIX_2_H
 #define CASA_MATRIX_2_H
@@ -85,58 +83,58 @@ namespace casacore { //#Begin casa namespace
 // index operations will be bounds-checked. Neither of these should
 // be defined for production code.
 
-template<typename T, typename Alloc> class Matrix : public Array<T, Alloc>
+template<typename T> class Matrix : public Array<T>
 {
 public:
     // A Matrix of length zero in each dimension; zero origin.
-    Matrix(const Alloc& allocator = Alloc());
+    Matrix();
 
     // A Matrix with "l1" rows and "l2" columns.
     // Fill it with the initial value.
-    Matrix(size_t l1, size_t l2, const T &initialValue = T(), const Alloc& allocator = Alloc());
+    Matrix(size_t l1, size_t l2, const T &initialValue = T());
 
     // An uninitialized Matrix with "l1" rows and "l2" columns.
-    Matrix(size_t l1, size_t l2, typename Array<T, Alloc>::uninitializedType, const Alloc& allocator = Alloc());
+    Matrix(size_t l1, size_t l2, typename Array<T>::uninitializedType);
 
     // A matrix of shape with shape "len".
     // Fill it with the initial value.
-    Matrix(const IPosition &len, const T &initialValue = T(), const Alloc& allocator = Alloc());
+    Matrix(const IPosition &len, const T &initialValue = T());
 
     // An uninitialized matrix of shape with shape "len".
-    Matrix(const IPosition &len, typename Array<T, Alloc>::uninitializedType, const Alloc& allocator = Alloc());
+    Matrix(const IPosition &len, typename Array<T>::uninitializedType);
 
     // The copy/move constructor uses reference semantics.
-    Matrix(const Matrix<T, Alloc>& source);
-    Matrix(Matrix<T, Alloc>&& source);
+    Matrix(const Matrix<T>& source);
+    Matrix(Matrix<T>&& source);
 
     // Construct a Matrix by reference from "source". "source must have
     // ndim() of 2 or less.
-    Matrix(const Array<T, Alloc>& source);
-    Matrix(Array<T, Alloc>&& source);
+    Matrix(const Array<T>& source);
+    Matrix(Array<T>&& source);
 
     // Create an Matrix of a given shape from a pointer.
-    Matrix(const IPosition &shape, T *storage, StorageInitPolicy policy = COPY, const Alloc& allocator = Alloc());
+    Matrix(const IPosition &shape, T *storage, StorageInitPolicy policy = COPY);
     // Create an Matrix of a given shape from a pointer. Because the pointer
     // is const, a copy is always made.
     Matrix(const IPosition &shape, const T *storage);
 
     // Create an identity matrix of side length n. (Could not do this as a constructor
     // because of ambiguities with other constructors).
-    static Matrix<T, Alloc> identity (size_t n);
+    static Matrix<T> identity (size_t n);
 
     // Resize to the given shape
     // <group>
-    using Array<T, Alloc>::resize;
+    using Array<T>::resize;
     void resize(size_t nx, size_t ny, bool copyValues=false);
      // </group>
 
-    Matrix<T, Alloc>& operator=(const Matrix<T, Alloc>& source)
+    Matrix<T>& operator=(const Matrix<T>& source)
     { return assign_conforming(source); }
-    Matrix<T, Alloc>& operator=(Matrix<T, Alloc>&& source)
+    Matrix<T>& operator=(Matrix<T>&& source)
     { return assign_conforming(std::move(source)); }
-    Matrix<T, Alloc>& operator=(const Array<T, Alloc>& source)
+    Matrix<T>& operator=(const Array<T>& source)
     { return assign_conforming(source); }
-    Matrix<T, Alloc>& operator=(Array<T, Alloc>&& source)
+    Matrix<T>& operator=(Array<T>&& source)
     { return assign_conforming(std::move(source)); }
    
     // Copy the values from other to this Matrix. If this matrix has zero
@@ -145,31 +143,31 @@ public:
     // Note that the assign function can be used to assign a
     // non-conforming matrix.
     // <group>
-    Matrix<T, Alloc>& assign_conforming(const Matrix<T, Alloc>& source)
-    { Array<T, Alloc>::assign_conforming(source); return *this; }
-    Matrix<T, Alloc>& assign_conforming(Matrix<T, Alloc>&& source)
-    { Array<T, Alloc>::assign_conforming(std::move(source)); return *this; }
+    Matrix<T>& assign_conforming(const Matrix<T>& source)
+    { Array<T>::assign_conforming(source); return *this; }
+    Matrix<T>& assign_conforming(Matrix<T>&& source)
+    { Array<T>::assign_conforming(std::move(source)); return *this; }
     
-    Matrix<T, Alloc>& assign_conforming(const Array<T, Alloc>& source)
+    Matrix<T>& assign_conforming(const Array<T>& source)
     {
       // TODO Should be supported by the Array class,
       // see Cube::operator=(const Array&)
       
       if (source.ndim() == 2) {
-        Array<T, Alloc>::assign_conforming(source);
+        Array<T>::assign_conforming(source);
       } else {
         // This might work if a.ndim == 1 or 2
-        (*this) = Matrix<T, Alloc>(source);
+        (*this) = Matrix<T>(source);
       }
       return *this;
     }
    
-    Matrix<T, Alloc>& assign_conforming(Array<T, Alloc>&& source)
+    Matrix<T>& assign_conforming(Array<T>&& source)
     {
       if (source.ndim() == 2) {
-        Array<T, Alloc>::assign_conforming(std::move(source));
+        Array<T>::assign_conforming(std::move(source));
       } else {
-        (*this) = Matrix<T, Alloc>(std::move(source));
+        (*this) = Matrix<T>(std::move(source));
       }
       return *this;
     }
@@ -177,21 +175,21 @@ public:
 
     // Copy val into every element of this Matrix; i.e. behaves as if
     // val were a constant conformant matrix.
-    Array<T, Alloc>& operator=(const T &val)
-      { return Array<T, Alloc>::operator=(val); }
+    Array<T>& operator=(const T &val)
+      { return Array<T>::operator=(val); }
 
     // Copy to this those values in marray whose corresponding elements
     // in marray's mask are true.
-    Matrix<T, Alloc>& assign_conforming (const MaskedArray<T> &marray)
-      { Array<T, Alloc>::assign_conforming(marray); return *this; }
+    Matrix<T>& assign_conforming (const MaskedArray<T> &marray)
+      { Array<T>::assign_conforming(marray); return *this; }
 
     // Single-pixel addressing. If AIPS_ARRAY_INDEX_CHECK is defined,
     // bounds checking is performed.
     // <group>
     T &operator()(const IPosition &i)
-      { return Array<T, Alloc>::operator()(i); }
+      { return Array<T>::operator()(i); }
     const T &operator()(const IPosition &i) const 
-      { return Array<T, Alloc>::operator()(i); }
+      { return Array<T>::operator()(i); }
     T &operator()(size_t i1, size_t i2)
       {
 	return this->contiguous_p ? this->begin_p[i1 + i2*yinc()] :
@@ -212,11 +210,11 @@ public:
 
     // Return a MaskedArray.
     MaskedArray<T> operator() (const LogicalArray &mask) const
-      { return Array<T, Alloc>::operator() (mask); }
+      { return Array<T>::operator() (mask); }
 
     // Return a MaskedArray.
     MaskedArray<T> operator() (const LogicalArray &mask)
-      { return Array<T, Alloc>::operator() (mask); }
+      { return Array<T>::operator() (mask); }
 
     // </group>
 
@@ -229,33 +227,33 @@ public:
 
     // Return a MaskedArray.
     MaskedArray<T> operator() (const MaskedLogicalArray &mask) const
-      { return Array<T, Alloc>::operator() (mask); }
+      { return Array<T>::operator() (mask); }
 
     // Return a MaskedArray.
     MaskedArray<T> operator() (const MaskedLogicalArray &mask)
-      { return Array<T, Alloc>::operator() (mask); }
+      { return Array<T>::operator() (mask); }
 
     // </group>
 
 
     // Returns a reference to the i'th row.
     // <group>
-    Vector<T, Alloc> row(size_t i);
-    const Vector<T, Alloc> row(size_t i) const;
+    Vector<T> row(size_t i);
+    const Vector<T> row(size_t i) const;
     // </group>
 
     // Returns a reference to the j'th column
     // <group>
-    Vector<T, Alloc> column(size_t j);
-    const Vector<T, Alloc> column(size_t j) const;
+    Vector<T> column(size_t j);
+    const Vector<T> column(size_t j) const;
     // </group>
 
     // Returns a diagonal from the Matrix. The Matrix must be square.
     // n==0 is the main diagonal. n>0 is above the main diagonal, n<0
     // is below it.
     // <group>
-    Vector<T, Alloc> diagonal(long long n=0);
-    const Vector<T, Alloc> diagonal(long long n=0) const;
+    Vector<T> diagonal(long long n=0);
+    const Vector<T> diagonal(long long n=0) const;
     // </group>
 
     // Take a slice of this matrix. Slices are always indexed starting
@@ -267,27 +265,27 @@ public:
     // vd(Slice(0,10),Slice(10,10)) = -1.0; // 10x10 sub-matrix set to -1.0
     // </srcblock>
     // <group>
-    Matrix<T, Alloc> operator()(const Slice &sliceX, const Slice &sliceY);
-    const Matrix<T, Alloc> operator()(const Slice &sliceX, const Slice &sliceY) const;
+    Matrix<T> operator()(const Slice &sliceX, const Slice &sliceY);
+    const Matrix<T> operator()(const Slice &sliceX, const Slice &sliceY) const;
     // </group>
 
     // Slice using IPositions. Required to be defined, otherwise the base
     // class versions are hidden.
     // <group>
-    Array<T, Alloc> operator()(const IPosition &blc, const IPosition &trc,
+    Array<T> operator()(const IPosition &blc, const IPosition &trc,
 			const IPosition &incr)
-      { return Array<T, Alloc>::operator()(blc,trc,incr); }
-    const Array<T, Alloc> operator()(const IPosition &blc, const IPosition &trc,
+      { return Array<T>::operator()(blc,trc,incr); }
+    const Array<T> operator()(const IPosition &blc, const IPosition &trc,
                               const IPosition &incr) const
-      { return Array<T, Alloc>::operator()(blc,trc,incr); }
-    Array<T, Alloc> operator()(const IPosition &blc, const IPosition &trc)
-      { return Array<T, Alloc>::operator()(blc,trc); }
-    const Array<T, Alloc> operator()(const IPosition &blc, const IPosition &trc) const
-      { return Array<T, Alloc>::operator()(blc,trc); }
-    Array<T, Alloc> operator()(const Slicer& slicer)
-      { return Array<T, Alloc>::operator()(slicer); }
-    const Array<T, Alloc> operator()(const Slicer& slicer) const
-      { return Array<T, Alloc>::operator()(slicer); }
+      { return Array<T>::operator()(blc,trc,incr); }
+    Array<T> operator()(const IPosition &blc, const IPosition &trc)
+      { return Array<T>::operator()(blc,trc); }
+    const Array<T> operator()(const IPosition &blc, const IPosition &trc) const
+      { return Array<T>::operator()(blc,trc); }
+    Array<T> operator()(const Slicer& slicer)
+      { return Array<T>::operator()(slicer); }
+    const Array<T> operator()(const Slicer& slicer) const
+      { return Array<T>::operator()(slicer); }
     // </group>
 
     // The length of each axis of the Matrix.
@@ -312,7 +310,7 @@ protected:
     // Remove the degenerate axes from other and store result in this matrix.
     // An exception is thrown if removing degenerate axes does not result
     // in a matrix.
-    virtual void doNonDegenerate(const Array<T, Alloc> &other,
+    virtual void doNonDegenerate(const Array<T> &other,
                                  const IPosition &ignoreAxes) override;
                                  
     virtual size_t fixedDimensionality() const override { return 2; }
