@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef CASA_VECTORITER_2_H
 #define CASA_VECTORITER_2_H
@@ -69,22 +67,22 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 // }
 // </srcblock>
 
-template<typename T, typename Alloc=std::allocator<T>>
-class VectorIterator : public ArrayIterator<T, Alloc>
+template<typename T>
+class VectorIterator : public ArrayIterator<T>
 {
 public:
     // Iterate by vector cursors through array "a".
     // The vector cursor is taken for the given axis.
-    explicit VectorIterator(Array<T, Alloc> &a, size_t axis=0);
+    explicit VectorIterator(Array<T> &a, size_t axis=0);
 
     // Return a Vector at the current position.
-    Vector<T, Alloc> &vector() {return *(Vector<T, Alloc> *)this->ap_p.get();}
+    Vector<T> &vector() {return *(Vector<T> *)this->ap_p.get();}
 
 private:
     // Not implemented.
-    VectorIterator(const VectorIterator<T, Alloc> &) = delete;
+    VectorIterator(const VectorIterator<T> &) = delete;
     // Not implemented.
-    VectorIterator<T, Alloc> &operator=(const VectorIterator<T, Alloc> &) = delete;
+    VectorIterator<T> &operator=(const VectorIterator<T> &) = delete;
 };
 
 // 
@@ -99,19 +97,19 @@ private:
 //        ArrayIterator.
 // </note>
 
-template<typename T, typename Alloc=std::allocator<T>> class ReadOnlyVectorIterator 
+template<typename T> class ReadOnlyVectorIterator
 {
 public:
     // <group>
-    explicit ReadOnlyVectorIterator(const Array<T, Alloc> &a, size_t axis=0)
+    explicit ReadOnlyVectorIterator(const Array<T> &a, size_t axis=0)
       : vi(const_cast<Array<T>&>(a), axis) {}
 
     void next()   {vi.next();}
     void reset() {vi.origin();}
     void origin() {vi.origin();}
     
-    const Array<T, Alloc> &array() {return vi.array();}
-    const Vector<T, Alloc> &vector() {return vi.vector();}
+    const Array<T> &array() {return vi.array();}
+    const Vector<T> &vector() {return vi.vector();}
 
     bool atStart() const {return vi.atStart();}
     bool pastEnd() const {return vi.pastEnd();}
@@ -121,11 +119,11 @@ public:
     // </group>
 private:
     // Not implemented.
-    ReadOnlyVectorIterator(const ReadOnlyVectorIterator<T, Alloc> &) = delete;
+    ReadOnlyVectorIterator(const ReadOnlyVectorIterator<T> &) = delete;
     // Not implemented.
-    ReadOnlyVectorIterator<T, Alloc> &operator=(const ReadOnlyVectorIterator<T, Alloc> &) = delete;
+    ReadOnlyVectorIterator<T> &operator=(const ReadOnlyVectorIterator<T> &) = delete;
 
-    VectorIterator<T, Alloc> vi;
+    VectorIterator<T> vi;
 };
 
 
