@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef CASA_AIPSIO_H
 #define CASA_AIPSIO_H
@@ -179,27 +177,32 @@ public:
     explicit AipsIO (const String& fileName,
 		     ByteIO::OpenOption = ByteIO::Old,
 		     uInt filebufSize=65536,
-////		     uInt filebufSize=1048576,
-                     MultiFileBase* mfile=0);
+                     const std::shared_ptr<MultiFileBase>& = std::shared_ptr<MultiFileBase>());
 
     // Construct from a stream object derived from ByteIO.
     // This can for instance by used to use AipsIO on a file descriptor
     // for which a <linkto class=FilebufIO>FilebufIO</linkto>
     // object has been created.
     // The actual IO is done via a CanonicalIO object on top of it.
-    explicit AipsIO (ByteIO*);
+    explicit AipsIO (const std::shared_ptr<ByteIO>&);
 
     // Construct from a stream object derived from TypeIO, thus from
     // a stream on top of ByteIOn doing the possible conversions.
-    explicit AipsIO (TypeIO*);
+    explicit AipsIO (const std::shared_ptr<TypeIO>&);
 
     // Close if not done yet
     ~AipsIO();
 
+    // Copy constructor and assignment are not allowed.
+    AipsIO (const AipsIO&) = delete;
+    AipsIO& operator= (const AipsIO&) = delete;
+
     // Open/create file (either a regular file or a MultiFileBase virtual file).
     // An exception is thrown if the object contains an already open file.
-    void open (const String& fileName, ByteIO::OpenOption = ByteIO::Old,
-	       uInt filebufSize=65536, MultiFileBase* mfile=0);
+    void open (const String& fileName,
+               ByteIO::OpenOption = ByteIO::Old,
+               uInt filebufSize=65536,
+               const std::shared_ptr<MultiFileBase>& = std::shared_ptr<MultiFileBase>());
 
     // Open by connecting to the given byte stream.
     // This can for instance by used to use AipsIO on a file descriptor
@@ -207,11 +210,11 @@ public:
     // object has been created.
     // The actual IO is done via a CanonicalIO object on top of it.
     // An exception is thrown if the object contains an already open file.
-    void open (ByteIO*);
+    void open (const std::shared_ptr<ByteIO>&);
 
     // Open by connecting to the given typed byte stream.
     // An exception is thrown if the object contains an already open file.
-    void open (TypeIO*);
+    void open (const std::shared_ptr<TypeIO>&);
 
     // Close file opened
     void close();
@@ -452,9 +455,9 @@ private:
     // The cached object type.
     String       objectType_p;
     // The file object.
-    ByteIO*      file_p;
+    std::shared_ptr<ByteIO> file_p;
     // The actual IO object.
-    TypeIO*      io_p;
+    std::shared_ptr<TypeIO> io_p;
     // Is the file is seekable?
     Bool         seekable_p;
     // magic value to check sync.
