@@ -17,29 +17,21 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef CASA_STD_VECTOR_H
 #define CASA_STD_VECTOR_H
 
 //# Define the standard C++ include file. 
-//# This is an interim solution to cater for the SGI non-existence of
-//# them (e.g. <cstring>)
-//# Make sure any special macros are set
 #include <casacore/casa/aips.h>
-
-#if !defined(AIPS_SGI)
 #include <vector>
-using std::vector;
-#else
-#include <vector.h>
-#endif
 
+namespace casacore { //# NAMESPACE CASACORE - BEGIN
+  using std::vector;
+}
 
 #endif
