@@ -17,14 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//#
-//# $Id$
 
 #include <casacore/images/Images/ImageFITSConverter.h>
 #include <casacore/images/Images/PagedImage.h>
@@ -865,10 +862,10 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     }
     //
     fhi.applyMask = False;
-    fhi.pMask = 0;
+    fhi.pMask.reset();
     if (image.isMasked()) {
       fhi.applyMask = True;
-      fhi.pMask = new Array<Bool>(IPosition(0,0));
+      fhi.pMask = std::make_shared<Array<Bool>>(IPosition(0,0));
     }
     //
     // Find scale factors
