@@ -16,13 +16,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id: Array.h 21545 2015-01-22 19:36:35Z gervandiepen $
 
 #ifndef LATTICES_MASKEDLATTICESTATSDATAPROVIDER_H
 #define LATTICES_MASKEDLATTICESTATSDATAPROVIDER_H
@@ -118,7 +116,7 @@ public:
 
 private:
 
-	CountedPtr<RO_MaskedLatticeIterator<T> > _iter;
+	std::shared_ptr<RO_MaskedLatticeIterator<T>> _iter;
 	Array<T> _currentSlice;
 	Array<Bool> _currentMaskSlice;
 	const T* _currentPtr;
