@@ -237,7 +237,7 @@ void MCFrequency::doConvert(MVFrequency &in,
 	getLat(g3);
       g2 = MeasTable::diurnalAber(lengthE, tdbTime);
       // *MVPOS1 = MVDirection(C::pi_2 + g1, 0.0);
-      updatePosition(C::pi_2 + g1, 0.0, *MVPOS1);
+      updatePosition(M_PI_2 + g1, 0.0, *MVPOS1);
       MVPOS1->readjust(g2 * cos(g3));
       MFrequency::Ref::frameDirection(outref, inref).
 	getApp(*MVDIR1);
@@ -270,7 +270,7 @@ void MCFrequency::doConvert(MVFrequency &in,
 	getLat(g3);
       g2 = MeasTable::diurnalAber(lengthE, tdbTime);
       // *MVPOS1 = MVDirection(C::pi_2 + g1, 0.0);
-      updatePosition(C::pi_2 + g1, 0.0, *MVPOS1);
+      updatePosition(M_PI_2 + g1, 0.0, *MVPOS1);
       MVPOS1->readjust(g2*cos(g3));
       MFrequency::Ref::frameDirection(outref, inref).
 	getApp(*MVDIR1);
