@@ -200,7 +200,7 @@ void MCRadialVelocity::doConvert(MVRadialVelocity &in,
       MRadialVelocity::Ref::framePosition(outref, inref).
 	getLat(g3);
       g2 = MeasTable::diurnalAber(lengthE, tdbTime);
-      *MVPOS1 = MVDirection(C::pi_2 + g1, 0.0);
+      *MVPOS1 = MVDirection(M_PI_2 + g1, 0.0);
       MVPOS1->readjust(g2 * cos(g3));
       MRadialVelocity::Ref::frameDirection(outref, inref).
 	getApp(*MVDIR1);
@@ -232,7 +232,7 @@ void MCRadialVelocity::doConvert(MVRadialVelocity &in,
       MRadialVelocity::Ref::framePosition(inref, outref).
 	getLat(g3);
       g2 = MeasTable::diurnalAber(lengthE, tdbTime);
-      *MVPOS1 = MVDirection(C::pi_2 + g1, 0.0);
+      *MVPOS1 = MVDirection(M_PI_2 + g1, 0.0);
       MVPOS1->readjust(g2 * cos(g3));
       MRadialVelocity::Ref::frameDirection(outref, inref).
 	getApp(*MVDIR1);
