@@ -56,7 +56,7 @@ namespace casacore {
     Vector<Double> R0(3),A1(3),V1(3),V2(6),V3(3);
 
     //  Radians per year to arcsec per century
-    const Double PMF=100e0*60e0*60e0*360e0/C::_2pi;
+    const Double PMF=100e0*60e0*60e0*360e0/(2.0*M_PI);
 
     //  Functions
     //  Double sla_EPJ,sla_EPB2D,sla_DRANRM
