@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 
 //# Includes
@@ -48,7 +46,7 @@ TableMeasColumn::TableMeasColumn (const Table& tab,
 : itsNvals      (0),
   itsTabDataCol (tab, columnName)
 {
-  itsDescPtr = TableMeasDescBase::reconstruct (tab, columnName);
+  itsDescPtr.reset (TableMeasDescBase::reconstruct (tab, columnName));
   itsVarRefFlag = itsDescPtr->isRefCodeVariable();
   itsVarOffFlag = itsDescPtr->isOffsetVariable();
 }
