@@ -508,7 +508,7 @@ int main (int argc, const char* argv[])
         AlwaysAssert(v->getValue().size() == 5, AipsError);
         std::shared_ptr<Quantum<Vector<Double> > > w = col.getColumn("rad");
         AlwaysAssert(w->getValue().size() == 5, AipsError);
-        Double frac = C::pi/180;
+        Double frac = M_PI/180;
         for (uInt i=0; i<5; ++i) {
             AlwaysAssert(
                 near(w->getValue()[i], frac*v->getValue()[i]), AipsError
