@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef MS_MSANTENNAPARSE_H
 #define MS_MSANTENNAPARSE_H
@@ -173,7 +171,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     //# Data members.
   public:
     static MSAntennaParse* thisMSAParser;
-    static CountedPtr<MSSelectionErrorHandler> thisMSAErrorHandler;
+    static std::shared_ptr<MSSelectionErrorHandler> thisMSAErrorHandler;
     static void cleanupErrorHandler() {thisMSAErrorHandler.reset();}
     std::bitset<HIGHESTLEVEL> complexity;
   private:
