@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef MS_MSFEEDPARSE_H
 #define MS_MSFEEDPARSE_H
@@ -144,7 +142,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     //# Data members.
   public:
     static MSFeedParse* thisMSFParser;
-    static CountedPtr<MSSelectionErrorHandler> thisMSFErrorHandler;
+    static std::shared_ptr<MSSelectionErrorHandler> thisMSFErrorHandler;
     static void cleanupErrorHandler() {thisMSFErrorHandler.reset();}
   private:
     TableExprNode node_p;
