@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 
 #include <casacore/tables/DataMan/ISMBase.h>
@@ -35,7 +33,6 @@
 #include <casacore/tables/Tables/Table.h>
 #include <casacore/casa/Containers/Record.h>
 #include <casacore/casa/Utilities/ValType.h>
-#include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/IO/BucketCache.h>
 #include <casacore/casa/IO/BucketFile.h>
 #include <casacore/casa/IO/AipsIO.h>
@@ -291,11 +288,9 @@ void ISMBase::makeCache()
 				   ISMBucket::initCallBack,
 				   ISMBucket::deleteCallBack);
 	cache_p->resync (nbucketInit_p, nFreeBucket_p, firstFree_p);
-	AlwaysAssert (cache_p != 0, AipsError);
 	// Allocate a buffer for temporary storage by all ISM classes.
 	if (tempBuffer_p == 0) {
 	    tempBuffer_p = new char [bucketSize_p];
-	    AlwaysAssert (tempBuffer_p != 0, AipsError);
 	}
     }
 }
@@ -305,8 +300,7 @@ void ISMBase::makeIndex()
     if (index_p != 0) {
 	return;
     }
-    index_p = new ISMIndex (this);
-    AlwaysAssert (index_p != 0, AipsError);
+    index_p = new ISMIndex();
     file_p->open();
     readIndex();
 }
@@ -315,13 +309,13 @@ void ISMBase::readIndex()
 {
     file_p->seek (0);
     // Use the file given by the BucketFile object.
-    CountedPtr<ByteIO> fio = file_p->makeFilebufIO (1024);
-    TypeIO* tio;
+    std::shared_ptr<ByteIO> fio = file_p->makeFilebufIO (1024);
+    std::shared_ptr<TypeIO> tio;
     // It is stored in canonical or local format.
     if (asBigEndian()) {
-      tio = new CanonicalIO (fio.get());
+        tio.reset (new CanonicalIO (fio));
     }else{
-      tio = new LECanonicalIO (fio.get());
+        tio.reset (new LECanonicalIO (fio));
     }
     AipsIO os (tio);
     uInt version = os.getstart ("IncrementalStMan");
@@ -359,7 +353,6 @@ void ISMBase::readIndex()
     os.setpos (512 + off * bucketSize_p);
     index_p->get (os);
     os.close();
-    delete tio;
 }
 
 void ISMBase::writeIndex()
@@ -371,13 +364,13 @@ void ISMBase::writeIndex()
     // Write a few items at the beginning of the file.
     file_p->seek (0);
     // Use the file given by the BucketFile object.
-    CountedPtr<ByteIO> fio = file_p->makeFilebufIO (1024);
-    TypeIO* tio;
+    std::shared_ptr<ByteIO> fio = file_p->makeFilebufIO (1024);
+    std::shared_ptr<TypeIO> tio;
     // Store it in canonical or local format.
     if (asBigEndian()) {
-      tio = new CanonicalIO (fio.get());
+        tio.reset (new CanonicalIO (fio));
     }else{
-      tio = new LECanonicalIO (fio.get());
+        tio.reset (new LECanonicalIO (fio));
     }
     AipsIO os (tio);
     // The endian switch is a new feature. So only put it if little endian
@@ -400,7 +393,6 @@ void ISMBase::writeIndex()
     os.setpos (512 + off * bucketSize_p);
     index_p->put (os);
     os.close();
-    delete tio;
 }
     
 
@@ -549,9 +541,7 @@ void ISMBase::recreate()
     nFreeBucket_p = 0;
     firstFree_p   = -1;
     file_p = new BucketFile (fileName(), 0, False, multiFile());
-    AlwaysAssert (file_p != 0, AipsError);
-    index_p = new ISMIndex (this);
-    AlwaysAssert (index_p != 0, AipsError);
+    index_p = new ISMIndex();
     makeCache();
     //# Let the column objects create something if needed.
     for (uInt i=0; i<ncolumn(); i++) {
@@ -629,7 +619,6 @@ rownr_t ISMBase::open64 (rownr_t tabNrrow, AipsIO& ios)
     init();
     file_p = new BucketFile (fileName(), table().isWritable(),
                              0, False, multiFile());
-    AlwaysAssert (file_p != 0, AipsError);
     //# Westerbork MSs have a problem, because TMS used for a while
     //# the erroneous version of ISMBase.cc.
     //# So if we have an old ISM version, do a makeIndex to get
