@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef TABLES_SCALEDARRAYENGINE_H
 #define TABLES_SCALEDARRAYENGINE_H
@@ -189,6 +187,10 @@ public:
     // Destructor is mandatory.
     ~ScaledArrayEngine();
 
+    // Assignment is not needed and therefore forbidden.
+    ScaledArrayEngine<VirtualType,StoredType>& operator=
+                           (const ScaledArrayEngine<VirtualType,StoredType>&) = delete;
+
     // Return the type name of the engine (i.e. its class name).
     virtual String dataManagerType() const;
 
@@ -215,11 +217,6 @@ private:
     // (so it is made private).
     ScaledArrayEngine (const ScaledArrayEngine<VirtualType,StoredType>&);
 
-    // Assignment is not needed and therefore forbidden
-    // (so it is made private and not implemented).
-    ScaledArrayEngine<VirtualType,StoredType>& operator=
-                           (const ScaledArrayEngine<VirtualType,StoredType>&);
-
     // Clone the engine object.
     DataManager* clone() const;
 
