@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef TABLES_DVACENGINE_H
 #define TABLES_DVACENGINE_H
@@ -117,6 +115,9 @@ public:
     // Destructor is mandatory.
     virtual ~VACExampleVACEngine();
 
+    // Assignment is not needed and therefore forbidden.
+    VACExampleVACEngine& operator= (const VACExampleVACEngine&) = delete;
+
     // Clone the object.
     DataManager* clone() const;
 
@@ -146,10 +147,6 @@ private:
     // (so it is made private).
     VACExampleVACEngine (const VACExampleVACEngine&);
 
-    // Assignment is not needed and therefore forbidden
-    // (so it is made private).
-    VACExampleVACEngine& operator= (const VACExampleVACEngine&);
-
 
     // The target column names.
     String xTargetName_p;
