@@ -17,13 +17,11 @@
 //# 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 // This test is a very simplified clone of ASTRON's LofarStMan.
 // using the old DataManager interface.
@@ -789,7 +787,7 @@ void readTable()
   Table tab("tLofarStMan_tmp.data");
   uInt nrow = tab.nrow();
   uInt nbasel = nant*nant;
-  AlwaysAssertExit (nrow = ntime*nbasel);
+  AlwaysAssertExit (ntime*nbasel == nrow);
   AlwaysAssertExit (!tab.canAddRow());
   AlwaysAssertExit (!tab.canRemoveRow());
   AlwaysAssertExit (tab.canRemoveColumn(Vector<String>(1, "DATA")));
