@@ -17,13 +17,11 @@
 //# 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 // This test is a very simplified clone of ASTRON's LofarStMan
 // using the new DataManager interface.
@@ -73,6 +71,9 @@ namespace casacore {
   
     ~LofarStMan();
 
+    // Assignment cannot be used.
+    LofarStMan& operator= (const LofarStMan&) = delete;
+  
     // Clone this object.
     virtual DataManager* clone() const;
   
@@ -115,12 +116,9 @@ namespace casacore {
       { return ntime * nant * nant; }
 
   private:
-    // Copy constructor cannot be used.
-    LofarStMan (const LofarStMan& that);
+    // Copy constructor can only be used by clone.
+    LofarStMan (const LofarStMan&);
 
-    // Assignment cannot be used.
-    LofarStMan& operator= (const LofarStMan& that);
-  
     // Flush and optionally fsync the data.
     // It does nothing, and returns False.
     virtual Bool flush (AipsIO&, Bool doFsync);
@@ -460,7 +458,7 @@ namespace casacore {
   }
   void DataColumn::getArrayV (rownr_t rownr, ArrayBase& dataPtr)
   {
-    DebugAssert (dyype() == TpComplex, AipsError);
+    DebugAssert (dtype() == TpComplex, AipsError);
     Array<Complex>& arr = static_cast<Array<Complex>&>(dataPtr);
     indgen (arr, Complex(rownr, rownr+0.5));
   }
@@ -777,7 +775,7 @@ void readTable()
   Table tab("tLofarStMan_tmp.data");
   rownr_t nrow = tab.nrow();
   uInt nbasel = nant*nant;
-  AlwaysAssertExit (nrow = ntime*nbasel);
+  AlwaysAssertExit (ntime*nbasel == nrow);
   AlwaysAssertExit (!tab.canAddRow());
   AlwaysAssertExit (!tab.canRemoveRow());
   AlwaysAssertExit (tab.canRemoveColumn(Vector<String>(1, "DATA")));
