@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id: TaQLNode.h 21051 2011-04-20 11:46:29Z gervandiepen $
 
 //# Includes
 #include <casacore/tables/TaQL/ExprGroupAggrFuncArray.h>
@@ -1045,7 +1043,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
   }
   void TableExprGroupVariancesArrayDouble::finish()
   {
-    DebugAssert (itsNr.contiguousStorage()  &&  itsValue.contiguousStorage(),
+    DebugAssert (itsNr.contiguousStorage()  &&  itsValue.array().contiguousStorage(),
                  AipsError);
     Array<Double>::contiter itv = itsValue.array().cbegin();
     Array<Bool>::contiter itm = itsValue.wmask().cbegin();
@@ -1108,7 +1106,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
   }
   void TableExprGroupRmssArrayDouble::finish()
   {
-    DebugAssert (itsNr.contiguousStorage()  &&  itsValue.contiguousStorage(),
+    DebugAssert (itsNr.contiguousStorage()  &&  itsValue.array().contiguousStorage(),
                  AipsError);
     Array<Double>::contiter itv = itsValue.array().cbegin();
     Array<Bool>::contiter itm = itsValue.wmask().cbegin();
@@ -1247,7 +1245,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
   }
   void TableExprGroupVariancesArrayDComplex::finish()
   {
-    DebugAssert (itsNr.contiguousStorage()  &&  itsValue.contiguousStorage(),
+    DebugAssert (itsNr.contiguousStorage()  &&  itsValue.array().contiguousStorage(),
                  AipsError);
     Array<Double>::contiter itv = itsValue.array().cbegin();
     Array<Bool>::contiter itm = itsValue.wmask().cbegin();
