@@ -17,15 +17,15 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #include <casacore/tables/TaQL/ExprLogicNode.h>
+#include <casacore/tables/TaQL/ExprNodeSetOpt.h>
+#include <casacore/tables/TaQL/ExprNodeSet.h>
 #include <casacore/tables/TaQL/ExprDerNode.h>
 #include <casacore/tables/Tables/TableColumn.h>
 #include <casacore/tables/Tables/ColumnDesc.h>
@@ -41,8 +41,6 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 TableExprNodeEQBool::TableExprNodeEQBool (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtEQ)
 {}
-TableExprNodeEQBool::~TableExprNodeEQBool()
-{}
 Bool TableExprNodeEQBool::getBool (const TableExprId& id)
 {
     return lnode_p->getBool(id) == rnode_p->getBool(id);
@@ -51,8 +49,6 @@ Bool TableExprNodeEQBool::getBool (const TableExprId& id)
 TableExprNodeEQInt::TableExprNodeEQInt (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtEQ)
 {}
-TableExprNodeEQInt::~TableExprNodeEQInt()
-{}
 Bool TableExprNodeEQInt::getBool (const TableExprId& id)
 {
     return lnode_p->getInt(id) == rnode_p->getInt(id);
@@ -61,8 +57,6 @@ Bool TableExprNodeEQInt::getBool (const TableExprId& id)
 TableExprNodeEQDouble::TableExprNodeEQDouble (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtEQ)
 {}
-TableExprNodeEQDouble::~TableExprNodeEQDouble()
-{}
 Bool TableExprNodeEQDouble::getBool (const TableExprId& id)
 {
     return lnode_p->getDouble(id) == rnode_p->getDouble(id);
@@ -71,8 +65,6 @@ Bool TableExprNodeEQDouble::getBool (const TableExprId& id)
 TableExprNodeEQDComplex::TableExprNodeEQDComplex (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtEQ)
 {}
-TableExprNodeEQDComplex::~TableExprNodeEQDComplex()
-{}
 Bool TableExprNodeEQDComplex::getBool (const TableExprId& id)
 {
     return lnode_p->getDComplex(id) == rnode_p->getDComplex(id);
@@ -81,8 +73,6 @@ Bool TableExprNodeEQDComplex::getBool (const TableExprId& id)
 TableExprNodeEQString::TableExprNodeEQString (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtEQ)
 {}
-TableExprNodeEQString::~TableExprNodeEQString()
-{}
 Bool TableExprNodeEQString::getBool (const TableExprId& id)
 {
     return lnode_p->getString(id) == rnode_p->getString(id);
@@ -91,8 +81,6 @@ Bool TableExprNodeEQString::getBool (const TableExprId& id)
 TableExprNodeEQRegex::TableExprNodeEQRegex (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtEQ)
 {}
-TableExprNodeEQRegex::~TableExprNodeEQRegex()
-{}
 Bool TableExprNodeEQRegex::getBool (const TableExprId& id)
 {
     return rnode_p->getRegex(id).match (lnode_p->getString(id));
@@ -101,8 +89,6 @@ Bool TableExprNodeEQRegex::getBool (const TableExprId& id)
 TableExprNodeEQDate::TableExprNodeEQDate (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtEQ)
 {}
-TableExprNodeEQDate::~TableExprNodeEQDate()
-{}
 Bool TableExprNodeEQDate::getBool (const TableExprId& id)
 {
     return lnode_p->getDate(id) == rnode_p->getDate(id);
@@ -112,8 +98,6 @@ Bool TableExprNodeEQDate::getBool (const TableExprId& id)
 TableExprNodeNEBool::TableExprNodeNEBool (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtNE)
 {}
-TableExprNodeNEBool::~TableExprNodeNEBool()
-{}
 Bool TableExprNodeNEBool::getBool (const TableExprId& id)
 {
     return lnode_p->getBool(id) != rnode_p->getBool(id);
@@ -122,8 +106,6 @@ Bool TableExprNodeNEBool::getBool (const TableExprId& id)
 TableExprNodeNEInt::TableExprNodeNEInt (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtNE)
 {}
-TableExprNodeNEInt::~TableExprNodeNEInt()
-{}
 Bool TableExprNodeNEInt::getBool (const TableExprId& id)
 {
     return lnode_p->getInt(id) != rnode_p->getInt(id);
@@ -132,8 +114,6 @@ Bool TableExprNodeNEInt::getBool (const TableExprId& id)
 TableExprNodeNEDouble::TableExprNodeNEDouble (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtNE)
 {}
-TableExprNodeNEDouble::~TableExprNodeNEDouble()
-{}
 Bool TableExprNodeNEDouble::getBool (const TableExprId& id)
 {
     return lnode_p->getDouble(id) != rnode_p->getDouble(id);
@@ -142,8 +122,6 @@ Bool TableExprNodeNEDouble::getBool (const TableExprId& id)
 TableExprNodeNEDComplex::TableExprNodeNEDComplex (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtNE)
 {}
-TableExprNodeNEDComplex::~TableExprNodeNEDComplex()
-{}
 Bool TableExprNodeNEDComplex::getBool (const TableExprId& id)
 {
     return lnode_p->getDComplex(id) != rnode_p->getDComplex(id);
@@ -152,8 +130,6 @@ Bool TableExprNodeNEDComplex::getBool (const TableExprId& id)
 TableExprNodeNEString::TableExprNodeNEString (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtNE)
 {}
-TableExprNodeNEString::~TableExprNodeNEString()
-{}
 Bool TableExprNodeNEString::getBool (const TableExprId& id)
 {
     return lnode_p->getString(id) != rnode_p->getString(id);
@@ -162,8 +138,6 @@ Bool TableExprNodeNEString::getBool (const TableExprId& id)
 TableExprNodeNERegex::TableExprNodeNERegex (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtNE)
 {}
-TableExprNodeNERegex::~TableExprNodeNERegex()
-{}
 Bool TableExprNodeNERegex::getBool (const TableExprId& id)
 {
     return ! rnode_p->getRegex(id).match (lnode_p->getString(id));
@@ -172,8 +146,6 @@ Bool TableExprNodeNERegex::getBool (const TableExprId& id)
 TableExprNodeNEDate::TableExprNodeNEDate (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtNE)
 {}
-TableExprNodeNEDate::~TableExprNodeNEDate()
-{}
 Bool TableExprNodeNEDate::getBool (const TableExprId& id)
 {
     return lnode_p->getDate(id) != rnode_p->getDate(id);
@@ -183,8 +155,6 @@ Bool TableExprNodeNEDate::getBool (const TableExprId& id)
 TableExprNodeGTInt::TableExprNodeGTInt (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtGT)
 {}
-TableExprNodeGTInt::~TableExprNodeGTInt()
-{}
 Bool TableExprNodeGTInt::getBool (const TableExprId& id)
 {
     return lnode_p->getInt(id) > rnode_p->getInt(id);
@@ -193,8 +163,6 @@ Bool TableExprNodeGTInt::getBool (const TableExprId& id)
 TableExprNodeGTDouble::TableExprNodeGTDouble (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtGT)
 {}
-TableExprNodeGTDouble::~TableExprNodeGTDouble()
-{}
 Bool TableExprNodeGTDouble::getBool (const TableExprId& id)
 {
     return lnode_p->getDouble(id) > rnode_p->getDouble(id);
@@ -203,8 +171,6 @@ Bool TableExprNodeGTDouble::getBool (const TableExprId& id)
 TableExprNodeGTDComplex::TableExprNodeGTDComplex (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtGT)
 {}
-TableExprNodeGTDComplex::~TableExprNodeGTDComplex()
-{}
 Bool TableExprNodeGTDComplex::getBool (const TableExprId& id)
 {
     return lnode_p->getDComplex(id) > rnode_p->getDComplex(id);
@@ -213,8 +179,6 @@ Bool TableExprNodeGTDComplex::getBool (const TableExprId& id)
 TableExprNodeGTString::TableExprNodeGTString (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtGT)
 {}
-TableExprNodeGTString::~TableExprNodeGTString()
-{}
 Bool TableExprNodeGTString::getBool (const TableExprId& id)
 {
     return lnode_p->getString(id) > rnode_p->getString(id);
@@ -223,8 +187,6 @@ Bool TableExprNodeGTString::getBool (const TableExprId& id)
 TableExprNodeGTDate::TableExprNodeGTDate (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtGT)
 {}
-TableExprNodeGTDate::~TableExprNodeGTDate()
-{}
 Bool TableExprNodeGTDate::getBool (const TableExprId& id)
 {
     return lnode_p->getDate(id) > rnode_p->getDate(id);
@@ -234,8 +196,6 @@ Bool TableExprNodeGTDate::getBool (const TableExprId& id)
 TableExprNodeGEInt::TableExprNodeGEInt (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtGE)
 {}
-TableExprNodeGEInt::~TableExprNodeGEInt()
-{}
 Bool TableExprNodeGEInt::getBool (const TableExprId& id)
 {
     return lnode_p->getInt(id) >= rnode_p->getInt(id);
@@ -244,8 +204,6 @@ Bool TableExprNodeGEInt::getBool (const TableExprId& id)
 TableExprNodeGEDouble::TableExprNodeGEDouble (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtGE)
 {}
-TableExprNodeGEDouble::~TableExprNodeGEDouble()
-{}
 Bool TableExprNodeGEDouble::getBool (const TableExprId& id)
 {
     return lnode_p->getDouble(id) >= rnode_p->getDouble(id);
@@ -254,8 +212,6 @@ Bool TableExprNodeGEDouble::getBool (const TableExprId& id)
 TableExprNodeGEDComplex::TableExprNodeGEDComplex (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtGE)
 {}
-TableExprNodeGEDComplex::~TableExprNodeGEDComplex()
-{}
 Bool TableExprNodeGEDComplex::getBool (const TableExprId& id)
 {
     return lnode_p->getDComplex(id) >= rnode_p->getDComplex(id);
@@ -264,8 +220,6 @@ Bool TableExprNodeGEDComplex::getBool (const TableExprId& id)
 TableExprNodeGEString::TableExprNodeGEString (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtGE)
 {}
-TableExprNodeGEString::~TableExprNodeGEString()
-{}
 Bool TableExprNodeGEString::getBool (const TableExprId& id)
 {
     return lnode_p->getString(id) >= rnode_p->getString(id);
@@ -274,8 +228,6 @@ Bool TableExprNodeGEString::getBool (const TableExprId& id)
 TableExprNodeGEDate::TableExprNodeGEDate (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtGE)
 {}
-TableExprNodeGEDate::~TableExprNodeGEDate()
-{}
 Bool TableExprNodeGEDate::getBool (const TableExprId& id)
 {
     return lnode_p->getDate(id) >= rnode_p->getDate(id);
@@ -286,79 +238,117 @@ TableExprNodeINInt::TableExprNodeINInt (const TableExprNodeRep& node,
                                         Bool)
 : TableExprNodeBinary (NTBool, node, OtIN)
 {}
-void TableExprNodeINInt::convertConstChild()
+void TableExprNodeINInt::optimize()
 {
-  if (rnode_p->isConstant()  &&  rnode_p->valueType() == VTArray) {
-    // Convert array to a set for lookup
-    MArray<Int64> values = rnode_p->getArrayInt(0);
+  doOptimize (rnode_p);
+}
+void TableExprNodeINInt::doOptimize (TENShPtr& rnode)
+{
+  if (rnode->isConstant()  &&  rnode->valueType() == VTArray) {
+    // Convert a constant array for faster lookup.
+    MArray<Int64> values = rnode->getArrayInt(0);
     Array<Int64> arr(values.array());
     if (values.hasMask()) {
       // Remove masked elements.
       arr.reference (values.flatten());
     }
-    if (! arr.empty()) {
-      itsIndexSet.clear();
-      itsIndexSet.insert(arr.begin(), arr.end());
-    }
+    // Use an unordered_map for fast lookup.
+    rnode = std::make_shared<TableExprNodeSetOptUSet<Int64>>(*rnode, arr);
   }
 }
-TableExprNodeINInt::~TableExprNodeINInt()
-{}
 Bool TableExprNodeINInt::getBool (const TableExprId& id)
 {
     Int64 val = lnode_p->getInt (id);
-    if (itsIndexSet.size() > 0) {
-      return itsIndexSet.find(val) != itsIndexSet.end();
-    }
-    return rnode_p->hasInt (id, val);
+    return rnode_p->contains (id, val);
 }
 
 TableExprNodeINDouble::TableExprNodeINDouble (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtIN)
 {}
-TableExprNodeINDouble::~TableExprNodeINDouble()
-{}
+void TableExprNodeINDouble::optimize()
+{
+  doOptimize (rnode_p);
+}
+void TableExprNodeINDouble::doOptimize (TENShPtr& rnode)
+{
+  if (rnode->isConstant()  &&  rnode->valueType() == VTSet) {
+    TableExprNodeSet& set = dynamic_cast<TableExprNodeSet&>(*rnode);
+    if (!set.isSingle()  &&  !set.isDiscrete()) {
+      rnode = TableExprNodeSetOptContSetBase<Double>::transform (set);
+    }
+  }
+}
 Bool TableExprNodeINDouble::getBool (const TableExprId& id)
 {
-    return rnode_p->hasDouble (id, lnode_p->getDouble (id));
+    return rnode_p->contains (id, lnode_p->getDouble (id));
 }
 
 TableExprNodeINDComplex::TableExprNodeINDComplex (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtIN)
 {}
-TableExprNodeINDComplex::~TableExprNodeINDComplex()
-{}
 Bool TableExprNodeINDComplex::getBool (const TableExprId& id)
 {
-    return rnode_p->hasDComplex (id, lnode_p->getDComplex (id));
+    return rnode_p->contains (id, lnode_p->getDComplex (id));
 }
 
 TableExprNodeINString::TableExprNodeINString (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtIN)
 {}
-TableExprNodeINString::~TableExprNodeINString()
-{}
+void TableExprNodeINString::optimize()
+{
+  doOptimize (rnode_p);
+}
+void TableExprNodeINString::doOptimize (TENShPtr& rnode)
+{
+  if (rnode->isConstant()) {
+    if (rnode->valueType() == VTSet) {
+      // A constant set with continuous intervals can be made faster.
+      TableExprNodeSet& set = dynamic_cast<TableExprNodeSet&>(*rnode);
+      if (!set.isSingle()  &&  !set.isDiscrete()) {
+        rnode = TableExprNodeSetOptContSetBase<String>::transform (set);
+      }
+    } else if (rnode->valueType() == VTArray) {
+      // Convert a constant array to an unordered_set for faster lookup.
+      MArray<String> values = rnode->getArrayString(0);
+      Array<String> arr(values.array());
+      if (values.hasMask()) {
+        // Remove masked elements.
+        arr.reference (values.flatten());
+      }
+      rnode = std::make_shared<TableExprNodeSetOptUSet<String>>(*rnode, arr);
+    }
+  }
+}
 Bool TableExprNodeINString::getBool (const TableExprId& id)
 {
-    return rnode_p->hasString (id, lnode_p->getString (id));
+    return rnode_p->contains (id, lnode_p->getString (id));
 }
 
 TableExprNodeINDate::TableExprNodeINDate (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtIN)
 {}
-TableExprNodeINDate::~TableExprNodeINDate()
-{}
+void TableExprNodeINDate::optimize()
+{
+  doOptimize (rnode_p);
+}
+void TableExprNodeINDate::doOptimize (TENShPtr& rnode)
+{
+  if (rnode->isConstant()  &&  rnode->valueType() == VTSet) {
+    TableExprNodeSet& set = dynamic_cast<TableExprNodeSet&>(*rnode);
+    if (!set.isSingle()  &&  !set.isDiscrete()) {
+      rnode = TableExprNodeSetOptContSetBase<Double>::transform (set);
+    }
+  }
+}
 Bool TableExprNodeINDate::getBool (const TableExprId& id)
 {
-    return rnode_p->hasDate (id, lnode_p->getDate (id));
+    return rnode_p->contains (id, lnode_p->getDate (id));
 }
 
 
 TableExprNodeOR::TableExprNodeOR (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtOR)
 {}
-TableExprNodeOR::~TableExprNodeOR()
-{}
 Bool TableExprNodeOR::getBool (const TableExprId& id)
 {
     return lnode_p->getBool(id) || rnode_p->getBool(id);
@@ -368,8 +358,6 @@ Bool TableExprNodeOR::getBool (const TableExprId& id)
 TableExprNodeAND::TableExprNodeAND (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtAND)
 {}
-TableExprNodeAND::~TableExprNodeAND()
-{}
 Bool TableExprNodeAND::getBool (const TableExprId& id)
 {
     return lnode_p->getBool(id) && rnode_p->getBool(id);
@@ -379,8 +367,6 @@ Bool TableExprNodeAND::getBool (const TableExprId& id)
 TableExprNodeNOT::TableExprNodeNOT (const TableExprNodeRep& node)
 : TableExprNodeBinary (NTBool, node, OtNOT)
 {}
-TableExprNodeNOT::~TableExprNodeNOT()
-{}
 Bool TableExprNodeNOT::getBool (const TableExprId& id)
 {
   return ! lnode_p->getBool(id);
