@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id: ExprLogicNodeArray.h 21262 2012-09-07 12:38:36Z gervandiepen $
 
 #ifndef TABLES_EXPRLOGICNODEARRAY_H
 #define TABLES_EXPRLOGICNODEARRAY_H
@@ -791,6 +789,8 @@ public:
 // This is defined for all data types.
 // Only the Bool get function is defined, because the result of a
 // compare is always a Bool.
+// The right hand side can be optimized if it contains a constant array which
+// can be replaced by an std::unordered_set<Int64> or a Block<Bool>.
 // </synopsis> 
 
 class TableExprNodeArrayINInt : public TableExprNodeArray
@@ -798,7 +798,8 @@ class TableExprNodeArrayINInt : public TableExprNodeArray
 public:
     TableExprNodeArrayINInt (const TableExprNodeRep&);
     ~TableExprNodeArrayINInt();
-    MArray<Bool> getArrayBool (const TableExprId& id);
+    virtual void optimize() override;
+    virtual MArray<Bool> getArrayBool (const TableExprId& id) override;
 };
 
 
@@ -828,7 +829,8 @@ class TableExprNodeArrayINDouble : public TableExprNodeArray
 public:
     TableExprNodeArrayINDouble (const TableExprNodeRep&);
     ~TableExprNodeArrayINDouble();
-    MArray<Bool> getArrayBool (const TableExprId& id);
+    virtual void optimize() override;
+    MArray<Bool> getArrayBool (const TableExprId& id) override;
 };
 
 
@@ -881,6 +883,8 @@ public:
 // This is defined for all data types.
 // Only the Bool get function is defined, because the result of a
 // compare is always a Bool.
+// The right hand side can be optimized if it contains a constant array which
+// can be replaced by an std::unordered_set<String>
 // </synopsis> 
 
 class TableExprNodeArrayINString : public TableExprNodeArray
@@ -888,7 +892,8 @@ class TableExprNodeArrayINString : public TableExprNodeArray
 public:
     TableExprNodeArrayINString (const TableExprNodeRep&);
     ~TableExprNodeArrayINString();
-    MArray<Bool> getArrayBool (const TableExprId& id);
+    virtual void optimize() override;
+    virtual MArray<Bool> getArrayBool (const TableExprId& id) override;
 };
 
 
@@ -918,7 +923,8 @@ class TableExprNodeArrayINDate : public TableExprNodeArray
 public:
     TableExprNodeArrayINDate (const TableExprNodeRep&);
     ~TableExprNodeArrayINDate();
-    MArray<Bool> getArrayBool (const TableExprId& id);
+    virtual void optimize() override;
+    MArray<Bool> getArrayBool (const TableExprId& id) override;
 };
 
 
