@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #include <thread>
 #include <utility>
@@ -37,6 +35,7 @@
 #include <casacore/tables/Tables/TableDesc.h>
 #include <casacore/tables/Tables/BaseColumn.h>
 #include <casacore/tables/TaQL/ExprNode.h>
+#include <casacore/tables/TaQL/ExprNodeUtil.h>
 #include <casacore/tables/Tables/BaseTabIter.h>
 #include <casacore/tables/DataMan/DataManager.h>
 #include <casacore/tables/Tables/TableError.h>
@@ -49,7 +48,6 @@
 #include <casacore/casa/Containers/Record.h>
 #include <casacore/casa/Containers/ValueHolder.h>
 #include <casacore/casa/Utilities/Sort.h>
-#include <casacore/casa/Utilities/PtrHolder.h>
 #include <casacore/casa/BasicSL/String.h>
 #include <casacore/casa/Utilities/GenSort.h>
 #include <casacore/casa/IO/AipsIO.h>
@@ -78,10 +76,8 @@ BaseTable::BaseTable (MPI_Comm mpiComm, const String& name, int option, rownr_t
 
 void BaseTable::BaseTableCommon (const String& name, int option, rownr_t nrrow)
 {
-    nrlink_p = 0;
     nrrow_p = nrrow;
     nrrowToAdd_p = 0;
-    tdescPtr_p = 0;
     name_p = name;
     option_p = option;
     noWrite_p = False;
@@ -123,37 +119,11 @@ BaseTable::~BaseTable()
     }
 }
 
-void BaseTable::link()
-{
-    nrlink_p++;
-#ifdef AIPS_TRACE
-    cout << "BaseTable::link:   " << nrlink_p << ' ' << name_p
-	 << ' ' << this << endl;
-#endif
-}
-
-void BaseTable::unlink (BaseTable* btp)
-{
-#ifdef AIPS_TRACE
-    cout << "BaseTable::unlink: " << btp->nrlink_p << ' ' << btp->name_p
-	 << ' ' << btp;
-    if (btp->nrlink_p == 1) {
-        cout << " gets destructed";
-    }
-    cout << endl;
-#endif
-    btp->nrlink_p--;
-    if (btp->nrlink_p == 0) {
-	delete btp;
-    }
-}
-
 Bool BaseTable::isNull() const
 {
   return False;
 }
 
-
 void BaseTable::scratchCallback (Bool isScratch, const String& oldName) const
 {
     if (Table::scratchCallback_p != 0) {
@@ -393,7 +363,8 @@ void BaseTable::setTableChanged()
 
 void BaseTable::markForDelete (Bool callback, const String& oldName)
 {
-    AlwaysAssert (!isNull(), AipsError);
+    //# Do not use virtual isNull as it can be called from the constructor.
+    AlwaysAssert (!BaseTable::isNull(), AipsError);
     Bool prev = delete_p;
     delete_p = True;
     //# Do callback if changed from non-scratch to scratch or if name changed.
@@ -407,7 +378,7 @@ void BaseTable::markForDelete (Bool callback, const String& oldName)
 }
 void BaseTable::unmarkForDelete (Bool callback, const String& oldName)
 {
-    AlwaysAssert (!isNull(), AipsError);
+    AlwaysAssert (!BaseTable::isNull(), AipsError);
     Bool prev = delete_p;
     delete_p = False;
     //# Do callback if changed from scratch to non-scratch.
@@ -513,7 +484,7 @@ void BaseTable::deepCopy (const String& newName,
 			  Bool noRows) const
 {
     if (valueCopy  ||  dataManagerInfo.nfields() > 0  ||  noRows) {
-      trueDeepCopy (newName, dataManagerInfo, stopt, tableOption,
+        trueDeepCopy (newName, dataManagerInfo, stopt, tableOption,
 		      endianFormat, noRows);
     } else {
         copy (newName, tableOption);
@@ -536,7 +507,9 @@ void BaseTable::trueDeepCopy (const String& newName,
 	       ("Table::deepCopy: new name equal to old name " + name_p);
     }
     //# Flush the data and subtables.
-    //# (cast is necessary to bypass non-constness).
+    //# The cast is necessary to bypass the constness of trueDeepCopy
+    //# while flush is const. Changing this requires changing of functions
+    //# copy and deepCopy as well, which could be done in the future.
     BaseTable* ncThis = const_cast<BaseTable*>(this);
     ncThis->flush (True, True);
     //# Prepare the copy (do some extra checks).
@@ -688,7 +661,7 @@ Bool BaseTable::rowOrder() const
     { return True; }
 
 //# By the default the table cannot return the storage of rownrs.
-Vector<rownr_t>* BaseTable::rowStorage()
+Vector<rownr_t>& BaseTable::rowStorage()
 {
     throw (TableInvOper ("rowStorage() not possible; table " + name_p +
                          " is no RefTable"));
@@ -696,11 +669,12 @@ Vector<rownr_t>* BaseTable::rowStorage()
 
 
 //# Sort a table.
-BaseTable* BaseTable::sort (const Block<String>& names,
-                            const Block<CountedPtr<BaseCompare> >& cmpObj,
-                            const Block<Int>& order, int option,
-                            std::shared_ptr<Vector<rownr_t>> sortIterBoundaries,
-                            std::shared_ptr<Vector<size_t>> sortIterKeyIdxChange)
+std::shared_ptr<BaseTable> BaseTable::sort
+(const Block<String>& names,
+ const Block<std::shared_ptr<BaseCompare>>& cmpObj,
+ const Block<Int>& order, int option,
+ std::shared_ptr<Vector<rownr_t>> sortIterBoundaries,
+ std::shared_ptr<Vector<size_t>> sortIterKeyIdxChange)
 
 {
     AlwaysAssert (!isNull(), AipsError);
@@ -727,50 +701,52 @@ BaseTable* BaseTable::sort (const Block<String>& names,
 }
 
 //# Do the actual sort.
-BaseTable* BaseTable::doSort (PtrBlock<BaseColumn*>& sortCol,
-                              const Block<CountedPtr<BaseCompare> >& cmpObj,
-                              const Block<Int>& order, int option,
-                              std::shared_ptr<Vector<rownr_t>> sortIterBoundaries,
-                              std::shared_ptr<Vector<size_t>> sortIterKeyIdxChange)
+std::shared_ptr<BaseTable> BaseTable::doSort
+(PtrBlock<BaseColumn*>& sortCol,
+ const Block<std::shared_ptr<BaseCompare>>& cmpObj,
+ const Block<Int>& order, int option,
+ std::shared_ptr<Vector<rownr_t>> sortIterBoundaries,
+ std::shared_ptr<Vector<size_t>> sortIterKeyIdxChange)
 {
     uInt nrkey = sortCol.nelements();
     //# Create a sort object.
     //# Pass all keys (and their data) to it.
     Sort sortobj;
-    Block<CountedPtr<ArrayBase> > data(nrkey);        // to remember data blocks
-    Block<CountedPtr<BaseCompare> > cmp(cmpObj);
+    Block<std::shared_ptr<ArrayBase>> data(nrkey);        // to remember data blocks
+    Block<std::shared_ptr<BaseCompare>> cmp(cmpObj);
     for (uInt i=0; i<nrkey; i++) {
         sortCol[i]->makeSortKey (sortobj, cmp[i], order[i], data[i]);
     }
     //# Create a reference table.
     //# This table will NOT be in row order.
     rownr_t nrrow = nrow();
-    RefTable* resultTable = makeRefTable (False, nrrow);
+    std::shared_ptr<RefTable> resultTable = makeRefTable (False, nrrow);
+    DebugAssert (static_cast<bool>(resultTable), AipsError);
     //# Now sort the table storing the row-numbers in the RefTable.
     //# Adjust rownrs in case source table is already a RefTable.
     //# Then delete possible allocated data blocks.
-    Vector<rownr_t>& rows = *(resultTable->rowStorage());
+    Vector<rownr_t>& rows = resultTable->rowStorage();
     //# Note that nrrow can change in case Sort::NoDuplicates was given.
     nrrow = sortobj.sort (rows, nrrow, option);
-    if(sortIterBoundaries && sortIterKeyIdxChange)
+    if(sortIterBoundaries && sortIterKeyIdxChange) {
         sortobj.unique(*sortIterBoundaries, *sortIterKeyIdxChange, rows);
+    }
     adjustRownrs (nrrow, rows, False);
     resultTable->setNrrow (nrrow);
     return resultTable;
 }
 
-RefTable* BaseTable::makeRefTable (Bool rowOrder, rownr_t initialNrrow)
+std::shared_ptr<RefTable> BaseTable::makeRefTable (Bool rowOrder,
+                                                   rownr_t initialNrrow)
 {
-    RefTable* rtp = new RefTable(this, rowOrder, initialNrrow);
-    return rtp;
+    return std::make_shared<RefTable>(this, rowOrder, initialNrrow);
 }
 
-
 //# No rownrs have to be adjusted and they are by default in ascending order.
 Bool BaseTable::adjustRownrs (rownr_t, Vector<rownr_t>&, Bool) const
     { return True; }
 
-BaseTable* BaseTable::select (rownr_t maxRow, rownr_t offset)
+std::shared_ptr<BaseTable> BaseTable::select (rownr_t maxRow, rownr_t offset)
 {
     if (offset > nrow()) {
         offset = nrow();
@@ -779,7 +755,7 @@ BaseTable* BaseTable::select (rownr_t maxRow, rownr_t offset)
         maxRow = nrow() - offset;
     }
     if (offset == 0  &&  maxRow == nrow()) {
-        return this;
+      return shared_from_this();    // pointer to itself
     }
     Vector<rownr_t> rownrs(maxRow);
     indgen(rownrs, rownr_t(offset));
@@ -787,8 +763,8 @@ BaseTable* BaseTable::select (rownr_t maxRow, rownr_t offset)
 }
 
 // Do the row selection.
-BaseTable* BaseTable::select (const TableExprNode& node,
-                              rownr_t maxRow, rownr_t offset)
+std::shared_ptr<BaseTable> BaseTable::select (const TableExprNode& node,
+                                              rownr_t maxRow, rownr_t offset)
 {
     // Check we don't deal with a null table.
     AlwaysAssert (!isNull(), AipsError);
@@ -813,16 +789,21 @@ BaseTable* BaseTable::select (const TableExprNode& node,
     // Now check if this table has been used for all columns.
     // Accept that the expression has no table, which can be the case for
     // UDFs in derivedmscal (since they have no function arguments).
-    if (!node.table().isNull()  &&  node.table().nrow() != this->nrow()) {
-      throw (TableInvExpr ("select expression for table " +
-                           node.table().tableName() +
-                           " is used on a differently sized table " + name_p));
+    std::vector<Table> tables
+      (TableExprNodeUtil::getNodeTables (node.getRep().get(), True));
+    if (! tables.empty()) {
+      if (TableExprNodeUtil::getCheckNRow(tables) != this->nrow()) {
+        throw (TableInvExpr ("select expression for table " +
+                             tables[0].tableName() +
+                             " is used on a differently sized table " + name_p));
+      }
     }
     //# Create a reference table, which will be in row order.
     //# Loop through all rows and add to reference table if true.
     //# Add the rownr of the root table (one may search a reference table).
     //# Adjust the row numbers to reflect row numbers in the root table.
-    SPtrHolder<RefTable> resultTable (makeRefTable (True, 0));
+    std::shared_ptr<RefTable> resultTable = makeRefTable (True, 0);
+    DebugAssert (static_cast<bool>(resultTable), AipsError);
     Bool val;
     rownr_t nrrow = nrow();
     TableExprId id;
@@ -842,98 +823,79 @@ BaseTable* BaseTable::select (const TableExprNode& node,
         }
       }
     }
-    adjustRownrs (resultTable->nrow(), *(resultTable->rowStorage()), False);
-    return resultTable.transfer();
+    adjustRownrs (resultTable->nrow(), resultTable->rowStorage(), False);
+    return resultTable;
 }
 
-BaseTable* BaseTable::select (const Vector<rownr_t>& rownrs)
+std::shared_ptr<BaseTable> BaseTable::select (const Vector<rownr_t>& rownrs)
 {
     AlwaysAssert (!isNull(), AipsError);
-    RefTable* rtp = new RefTable(this, rownrs);
-    return rtp;
+    return std::make_shared<RefTable>(this, rownrs);
 }
 
-BaseTable* BaseTable::select (const Block<Bool>& mask)
+std::shared_ptr<BaseTable> BaseTable::select (const Block<Bool>& mask)
 {
     AlwaysAssert (!isNull(), AipsError);
-    RefTable* rtp = new RefTable(this, Vector<Bool>(mask.begin(), mask.end()));
-    return rtp;
+    return std::make_shared<RefTable>(this, Vector<Bool>(mask.begin(), mask.end()));
 }
 
-BaseTable* BaseTable::project (const Block<String>& names)
+std::shared_ptr<BaseTable> BaseTable::project (const Block<String>& names)
 {
     AlwaysAssert (!isNull(), AipsError);
-    RefTable* rtp = new RefTable(this, Vector<String>(names.begin(), names.end()));
-    return rtp;
+    return std::make_shared<RefTable>(this, Vector<String>(names.begin(), names.end()));
 }
 
 
 //# And (intersect) 2 tables and return a new table.
-BaseTable* BaseTable::tabAnd (BaseTable* that)
+std::shared_ptr<BaseTable> BaseTable::tabAnd (BaseTable* that)
 {
     AlwaysAssert (!isNull(), AipsError);
     //# Check if both table have the same root.
     logicCheck (that);
     //# Anding a table with the (possibly sorted) root table gives the table.
     if (this->nrow() == this->root()->nrow()) {
-	return that;                                  // this is root
+      return that->shared_from_this();                    // this is root
     }
     if (that->nrow() == that->root()->nrow()) {
-	return this;                                  // that is root
+      return this->shared_from_this();                    // that is root
     }
     //# There is no root table involved, so we have to deal with RefTables.
-    //# Get both rownr arrays and sort them if not in row order.
-    //# Sorting means that the array is allocated on the heap, which has
-    //# to be deleted afterwards.
-    Bool allsw1, allsw2;
-    rownr_t* inx1;
-    rownr_t* inx2;
-    rownr_t nr1 = this->logicRows (inx1, allsw1);
-    rownr_t nr2 = that->logicRows (inx2, allsw2);
-    RefTable* rtp = makeRefTable (True, 0);           // will be in row order
-    rtp->refAnd (nr1, inx1, nr2, inx2);       // store rownrs in new RefTable
-    if (allsw1) {
-	delete [] inx1;
-    }
-    if (allsw2) {
-	delete [] inx2;
-    }
+    //# Get both rownr arrays which are sorted if not in row order.
+    Vector<rownr_t> r1 = this->logicRows();
+    Vector<rownr_t> r2 = that->logicRows();
+    // Create RefTable which will be in row order.
+    std::shared_ptr<RefTable> rtp = makeRefTable (True, 0);
+    DebugAssert (static_cast<bool>(rtp), AipsError);
+    // Store rownrs in new RefTable.
+    rtp->refAnd (r1.size(), r1.data(), r2.size(), r2.data());
     return rtp;
 }
 
 //# Or (union) 2 tables and return a new table.
-BaseTable* BaseTable::tabOr (BaseTable* that)
+std::shared_ptr<BaseTable> BaseTable::tabOr (BaseTable* that)
 {
     AlwaysAssert (!isNull(), AipsError);
-    //# Check if both table have the same root.
+    //# Check if both tables have the same root.
     logicCheck (that);
     //# Oring a table with the (possibly sorted) root table gives the root.
     if (this->nrow() == this->root()->nrow()
     ||  that->nrow() == that->root()->nrow()) {
-	return root();
+        return root()->shared_from_this();
     }
     //# There is no root table involved, so we have to deal with RefTables.
-    //# Get both rownr arrays and sort them if not in row order.
-    //# Sorting means that the array is allocated on the heap, which has
-    //# to be deleted afterwards.
-    Bool allsw1, allsw2;
-    rownr_t* inx1;
-    rownr_t* inx2;
-    rownr_t nr1 = this->logicRows (inx1, allsw1);
-    rownr_t nr2 = that->logicRows (inx2, allsw2);
-    RefTable* rtp = makeRefTable (True, 0);           // will be in row order
-    rtp->refOr (nr1, inx1, nr2, inx2);       // store rownrs in new RefTable
-    if (allsw1) {
-	delete [] inx1;
-    }
-    if (allsw2) {
-	delete [] inx2;
-    }
+    //# Get both rownr arrays which are sorted if not in row order.
+    Vector<rownr_t> r1 = this->logicRows();
+    Vector<rownr_t> r2 = that->logicRows();
+    // Create RefTable which will be in row order.
+    std::shared_ptr<RefTable> rtp = makeRefTable (True, 0);
+    DebugAssert (static_cast<bool>(rtp), AipsError);
+    // Store rownrs in new RefTable.
+    rtp->refOr (r1.size(), r1.data(), r2.size(), r2.data());
     return rtp;
 }
 
 //# Subtract (difference) 2 tables and return a new table.
-BaseTable* BaseTable::tabSub (BaseTable* that)
+std::shared_ptr<BaseTable> BaseTable::tabSub (BaseTable* that)
 {
     AlwaysAssert (!isNull(), AipsError);
     //# Check if both table have the same root.
@@ -947,27 +909,19 @@ BaseTable* BaseTable::tabSub (BaseTable* that)
 	return that->tabNot();
     }
     //# There is no root table involved, so we have to deal with RefTables.
-    //# Get both rownr arrays and sort them if not in row order.
-    //# Sorting means that the array is allocated on the heap, which has
-    //# to be deleted afterwards.
-    Bool allsw1, allsw2;
-    rownr_t* inx1;
-    rownr_t* inx2;
-    rownr_t nr1 = this->logicRows (inx1, allsw1);
-    rownr_t nr2 = that->logicRows (inx2, allsw2);
-    RefTable* rtp = makeRefTable (True, 0);           // will be in row order
-    rtp->refSub (nr1, inx1, nr2, inx2);       // store rownrs in new RefTable
-    if (allsw1) {
-	delete [] inx1;
-    }
-    if (allsw2) {
-	delete [] inx2;
-    }
+    //# Get both rownr arrays which are sorted if not in row order.
+    Vector<rownr_t> r1 = this->logicRows();
+    Vector<rownr_t> r2 = that->logicRows();
+    // Create RefTable which will be in row order.
+    std::shared_ptr<RefTable> rtp = makeRefTable (True, 0);
+    DebugAssert (static_cast<bool>(rtp), AipsError);
+    // Store rownrs in new RefTable.
+    rtp->refSub (r1.size(), r1.data(), r2.size(), r2.data());
     return rtp;
 }
 
 //# Xor 2 tables and return a new table.
-BaseTable* BaseTable::tabXor (BaseTable* that)
+std::shared_ptr<BaseTable> BaseTable::tabXor (BaseTable* that)
 {
     AlwaysAssert (!isNull(), AipsError);
     //# Check if both table have the same root.
@@ -980,27 +934,19 @@ BaseTable* BaseTable::tabXor (BaseTable* that)
 	return tabNot();
     }
     //# There is no root table involved, so we have to deal with RefTables.
-    //# Get both rownr arrays and sort them if not in row order.
-    //# Sorting means that the array is allocated on the heap, which has
-    //# to be deleted afterwards.
-    Bool allsw1, allsw2;
-    rownr_t* inx1;
-    rownr_t* inx2;
-    rownr_t nr1 = this->logicRows (inx1, allsw1);
-    rownr_t nr2 = that->logicRows (inx2, allsw2);
-    RefTable* rtp = makeRefTable (True, 0);           // will be in row order
-    rtp->refXor (nr1, inx1, nr2, inx2);       // store rownrs in new RefTable
-    if (allsw1) {
-	delete [] inx1;
-    }
-    if (allsw2) {
-	delete [] inx2;
-    }
+    //# Get both rownr arrays which are sorted if not in row order.
+    Vector<rownr_t> r1 = this->logicRows();
+    Vector<rownr_t> r2 = that->logicRows();
+    // Create RefTable which will be in row order.
+    std::shared_ptr<RefTable> rtp = makeRefTable (True, 0);
+    DebugAssert (static_cast<bool>(rtp), AipsError);
+    // Store rownrs in new RefTable.
+    rtp->refXor (r1.size(), r1.data(), r2.size(), r2.data());
     return rtp;
 }
 
 //# Negate a table (i.e. take all rows from the root not in table).
-BaseTable* BaseTable::tabNot()
+std::shared_ptr<BaseTable> BaseTable::tabNot()
 {
     AlwaysAssert (!isNull(), AipsError);
     //# Negating the (possibly sorted) root results in an empty table,
@@ -1008,17 +954,13 @@ BaseTable* BaseTable::tabNot()
 	return makeRefTable (True, 0);
     }
     //# There is no root table involved, so we have to deal with RefTables.
-    //# Get both rownr arrays and sort them if not in row order.
-    //# Sorting means that the array is allocated on the heap, which has
-    //# to be deleted.
-    Bool allsw1;
-    rownr_t* inx1;
-    rownr_t nr1 = this->logicRows (inx1, allsw1);
-    RefTable* rtp = makeRefTable (True, 0);           // will be in row order
-    rtp->refNot (nr1, inx1, root()->nrow());    // store rownrs in new RefTable
-    if (allsw1) {
-	delete [] inx1;
-    }
+    //# Get rownr array which is sorted if not in row order.
+    Vector<rownr_t> r1 = this->logicRows();
+    // Create RefTable which will be in row order.
+    std::shared_ptr<RefTable> rtp = makeRefTable (True, 0);
+    DebugAssert (static_cast<bool>(rtp), AipsError);
+    // Store rownrs in new RefTable.
+    rtp->refNot (r1.size(), r1.data(), root()->nrow());
     return rtp;
 }
 
@@ -1033,28 +975,24 @@ void BaseTable::logicCheck (BaseTable* that)
 //# Get the rownrs from the reference table.
 //# Note that rowStorage() throws an exception if it is not a RefTable.
 //# Sort them if not in row order.
-rownr_t BaseTable::logicRows (rownr_t*& inx, Bool& allsw)
+Vector<rownr_t> BaseTable::logicRows()
 {
     AlwaysAssert (!isNull(), AipsError);
-    allsw = False;
-    inx = RefTable::getStorage (*rowStorage());
-    rownr_t nr = nrow();
-    if (!rowOrder()) {
-	//# rows are not in order, so sort them.
-	//# They have to be copied, because the original should not be changed.
-	rownr_t* inxcp = new rownr_t[nr];
-	objcopy (inxcp, inx, nr);
-	GenSort<rownr_t>::sort (inxcp, nr);
-	inx = inxcp;
-	allsw = True;
+    Vector<rownr_t> rows (rowStorage());
+    if (rowOrder()) {
+      return rows;
     }
-    return nr;
+    //# rows are not in order, so sort them.
+    //# They have to be copied, because the original should not be changed.
+    Vector<rownr_t> rowscp (rows.copy());
+    GenSort<rownr_t>::sort (rowscp);
+    return rowscp;
 }
 
 
 BaseTableIterator* BaseTable::makeIterator
 (const Block<String>& names,
- const Block<CountedPtr<BaseCompare> >& cmpObj,
+ const Block<std::shared_ptr<BaseCompare>>& cmpObj,
  const Block<Int>& order, int option,
  bool cacheIterationBoundaries)
 {
@@ -1063,7 +1001,7 @@ BaseTableIterator* BaseTable::makeIterator
     ||  names.nelements() != cmpObj.nelements()) {
 	throw (TableInvOper ("TableIterator: Unequal block lengths"));
     }
-    BaseTableIterator* bti = new BaseTableIterator (this, names,
+    BaseTableIterator* bti = new BaseTableIterator (shared_from_this(), names,
                                                    cmpObj, order, option,
                                                    cacheIterationBoundaries);
     return bti;
@@ -1072,8 +1010,8 @@ BaseTableIterator* BaseTable::makeIterator
 
 const TableDesc& BaseTable::makeEmptyTableDesc() const
 {
-    if (tdescPtr_p.null()) {
-        const_cast<BaseTable*>(this)->tdescPtr_p = new TableDesc();
+    if (!tdescPtr_p) {
+      const_cast<BaseTable*>(this)->tdescPtr_p = std::make_shared<TableDesc>();
     }
     return *tdescPtr_p;
 }
@@ -1218,7 +1156,7 @@ void BaseTable::showStructure (ostream& os, Bool showDataMans, Bool showColumns,
         // Do not show if the subtable has the same root as this table.
         // This is needed to avoid endless recursion in case of SORTED_TABLE
         // in a MeasurementSet.
-        if (tab.isSameRoot (Table(this, False))) {
+        if (tab.isSameRoot (Table(this))) {
           os << endl << "Subtable " << keywords.name(i)
              << " references the parent table!!" << endl;
         } else {
