@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #include <casacore/casa/aips.h>
 #include <casacore/tables/Tables/PlainTable.h>
@@ -133,7 +131,7 @@ void PlainTable::PlainTableCommon (SetupNewTable& newtab, rownr_t nrrow,
     lockPtr_p->acquire (0, FileLocker::Write, 1);
     colSetPtr_p->linkToLockObject (lockPtr_p);
     //# Initialize the data managers.
-    Table tab(this, False);
+    Table tab(this);
     nrrowToAdd_p = nrrow;
     colSetPtr_p->initDataManagers (nrrow, bigEndian_p, tsmOption_p, tab);
     //# Initialize the columns if needed.
@@ -199,7 +197,7 @@ PlainTable::PlainTable (AipsIO&, uInt version, const String& tabname,
     Bool tableChanged;
     Block<Bool> dmChanged;
     lockSync_p.read (nrrow_p, ncolumn, tableChanged, dmChanged);
-    tdescPtr_p = new TableDesc ("", TableDesc::Scratch);
+    tdescPtr_p = std::make_shared<TableDesc>("", TableDesc::Scratch);
 
     //# Reopen the file to be sure that the internal stdio buffer is not reused.
     //# This is a terrible hack, but it works.
@@ -237,7 +235,7 @@ PlainTable::PlainTable (AipsIO&, uInt version, const String& tabname,
     }
 #endif
 
-    TableAttr attr (tableName(), isWritable(), lockOptions);
+    TableAttr attr (tableName(), PlainTable::isWritable(), lockOptions);
     tdescPtr_p->getFile (ios, attr);            // read description
     // Check if the given table type matches the type in the file.
     if ((! type.empty())  &&  type != tdescPtr_p->getType()) {
@@ -255,15 +253,15 @@ PlainTable::PlainTable (AipsIO&, uInt version, const String& tabname,
     }
     //# Construct and read the ColumnSet object.
     //# This will also construct the various DataManager objects.
-    colSetPtr_p = new ColumnSet (tdescPtr_p.get());
+    colSetPtr_p = std::make_shared<ColumnSet>(tdescPtr_p.get());
     colSetPtr_p->linkToTable (this);
     colSetPtr_p->linkToLockObject (lockPtr_p);
     if (version == 1) {
-	keywordSet().merge (tmp, RecordInterface::OverwriteDuplicates);
+        PlainTable::keywordSet().merge (tmp, RecordInterface::OverwriteDuplicates);
     }
     //# Create a Table object to be used internally by the data managers.
     //# Do not count it, otherwise a mutual dependency exists.
-    Table tab(this, False);
+    Table tab(this);
     nrrow_p = colSetPtr_p->getFile (ios, tab, nrrow_p, bigEndian_p,
                                     tsmOption_p);
     //# Read the TableInfo object.
@@ -319,7 +317,7 @@ void PlainTable::closeObject()
         timespec timet;
         timet.tv_sec = 1;
         timet.tv_nsec = 0;
-        while (isMultiUsed(False)) {
+        while (PlainTable::isMultiUsed(False)) {
             if (nTrys == 0) {
                 unmarkForDelete (False, "");
                 throw (TableError ("Table " + name_p + " cannot be deleted;"
@@ -465,11 +463,12 @@ void PlainTable::syncTable()
     // Something changed in the table file itself.
     // Reread it into a PlainTable object (don't add it to the cache).
     // Use a different locknr for it to preserve possible existing locks.
-    BaseTable* btab = Table::makeBaseTable
-                         (tableName(), "", Table::Old,
-			  TableLock(TableLock::PermanentLocking),
-			  TSMOption(TSMOption::Buffer,0,0), False, 1);
-    PlainTable* tab = (PlainTable*)btab;
+    std::shared_ptr<BaseTable> btab = Table::makeBaseTable
+      (tableName(), "", Table::Old,
+       TableLock(TableLock::PermanentLocking),
+       TSMOption(TSMOption::Buffer,0,0), False, 1);
+    PlainTable* tab = dynamic_cast<PlainTable*>(btab.get());
+    AlwaysAssert (tab, AipsError);
     TableAttr defaultAttr (tableName(), isWritable(), lockOptions());
     // Now check if all columns are the same.
     // Update the column keywords.
@@ -480,7 +479,6 @@ void PlainTable::syncTable()
     TableRecord& newKeySet = tab->keywordSet();
     newKeySet.setTableAttr (oldKeySet, defaultAttr);
     oldKeySet = newKeySet;
-    delete tab;
 }
 
 
@@ -525,10 +523,8 @@ void PlainTable::resync()
     // Skip the sync-ing in that case.
     uInt ncolumn;
     rownr_t nrrow;
-    if (! lockSync_p.read (nrrow, ncolumn, tableChanged,
-			   colSetPtr_p->dataManChanged())) {
-        tableChanged = False;
-    } else {
+    if (lockSync_p.read (nrrow, ncolumn, tableChanged,
+                         colSetPtr_p->dataManChanged())) {
         if (ncolumn != tableDesc().ncolumn()) {
             throw (TableError ("Table::resync cannot sync table " +
                                tableName() + "; another process "
@@ -702,7 +698,7 @@ void PlainTable::removeRow (rownr_t rownr)
 void PlainTable::addColumn (const ColumnDesc& columnDesc, Bool)
 {
     checkWritable("addColumn");
-    Table tab(this, False);
+    Table tab(this);
     colSetPtr_p->addColumn (columnDesc, bigEndian_p, tsmOption_p, tab);
     tableChanged_p = True;
 }
@@ -710,7 +706,7 @@ void PlainTable::addColumn (const ColumnDesc& columnDesc,
 			    const String& dataManager, Bool byName, Bool)
 {
     checkWritable("addColumn");
-    Table tab(this, False);
+    Table tab(this);
     colSetPtr_p->addColumn (columnDesc, dataManager, byName, bigEndian_p,
                             tsmOption_p, tab);
     tableChanged_p = True;
@@ -719,7 +715,7 @@ void PlainTable::addColumn (const ColumnDesc& columnDesc,
 			    const DataManager& dataManager, Bool)
 {
     checkWritable("addColumn");
-    Table tab(this, False);
+    Table tab(this);
     colSetPtr_p->addColumn (columnDesc, dataManager, bigEndian_p,
                             tsmOption_p, tab);
     tableChanged_p = True;
@@ -728,7 +724,7 @@ void PlainTable::addColumn (const TableDesc& tableDesc,
 			    const DataManager& dataManager, Bool)
 {
     checkWritable("addColumn");
-    Table tab(this, False);
+    Table tab(this);
     colSetPtr_p->addColumn (tableDesc, dataManager, bigEndian_p,
                             tsmOption_p, tab);
     tableChanged_p = True;
@@ -789,7 +785,6 @@ void PlainTable::setEndian (int endianFormat)
     if (endOpt == Table::AipsrcEndian) {
         String opt;
 	// Default "big" was used until version 10.1203.00.
-	////AipsrcValue<String>::find (opt, "table.endianformat", "big");
 	AipsrcValue<String>::find (opt, "table.endianformat", "local");
 	opt.downcase();
 	if (opt == "big") {
