@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef TABLES_TABLE_H
 #define TABLES_TABLE_H
@@ -39,6 +37,7 @@
 #include <casacore/casa/Containers/Record.h>
 #include <casacore/casa/Utilities/DataType.h>
 #include <casacore/casa/Utilities/Sort.h>
+#include <memory>
 
 #ifdef HAVE_MPI
 #include <mpi.h>
@@ -55,8 +54,8 @@ class Record;
 class TableExprNode;
 class DataManager;
 class IPosition;
+class TableExprInfo;
 template<class T> class Block;
-template<class T> class CountedPtr;
 
 
 // <summary>
@@ -376,6 +375,10 @@ public:
     // The recursive switch tells how to deal with that.
     Block<String> getPartNames (Bool recursive=False) const;
 
+    // Is this table the same as the other?
+    Bool isSameTable (const Table& other) const
+      { return baseTabPtr_p == other.baseTabPtr_p; }
+  
     // Is the root table of this table the same as that of the other one?
     Bool isSameRoot (const Table& other) const;
 
@@ -747,8 +750,6 @@ public:
     TableExprNode col (const String& columnName) const;
     TableExprNode col (const String& columnName,
 		       const Vector<String>& fieldNames) const;
-    TableExprNode keyCol (const String& name,
-			  const Vector<String>& fieldNames) const;
     // </group>
 
     // Create a TableExprNode object for the rownumber function.
@@ -845,11 +846,11 @@ public:
     // Sort on multiple columns. The principal column has to be the
     // first element in the Block of column names.
     // The order can be given per column.
-    // Provide some special comparisons via CountedPtrs of compare objects.
-    // A null CountedPtr means using the standard compare object
+    // Provide some special comparisons via std::shared_ptrs of compare objects.
+    // A null std::shared_ptr means using the standard compare object
     // from class <linkto class="ObjCompare:description">ObjCompare</linkto>.
     Table sort (const Block<String>& columnNames,
-		const Block<CountedPtr<BaseCompare> >& compareObjects,
+		const Block<std::shared_ptr<BaseCompare>>& compareObjects,
 		const Block<Int>& sortOrders,
 		int = Sort::ParSort) const;
     // </group>
@@ -1037,25 +1038,28 @@ public:
     // </group>
 
 protected:
-    BaseTable*  baseTabPtr_p;                 //# ptr to table representation
-    //# The isCounted_p flag is normally true.
-    //# Only for internally used Table objects (i.e. in the DataManager)
-    //# this flag is False, otherwise a mutual dependency would exist.
-    //# The DataManager has a Table object, which gets deleted by the
-    //# DataManager destructor. The DataManager gets deleted by the
-    //# PlainTable destructor, which gets called when the last Table
-    //# object gets destructed. That would never be the case if this
-    //# internally used Table object was counted.
-    Bool        isCounted_p;
-    //# Counter of last call to hasDataChanged.
+    // Shared pointer to count the references to the BaseTable object.
+    // The shared pointer can be null, so it is not counted which is necessary for
+    // the Table object in the DataManager. Otherwise mutual referencing would occur.
+    // Note that the BaseTable object contains a weak_ptr to itself which is the
+    // basis for all shared pointer counting.
+    std::shared_ptr<BaseTable> countedTabPtr_p;
+    // Pointer to BaseTable object which is always filled and always used.
+    // The shared_ptr above is only for reference counting.
+    BaseTable* baseTabPtr_p;
+    // Counter of last call to hasDataChanged.
     uInt        lastModCounter_p;
-    //# Pointer to the ScratchCallback function.
+    // Pointer to the ScratchCallback function.
     static ScratchCallback* scratchCallback_p;
 
 
-    // Construct a Table object from a BaseTable*.
-    // By default the object gets counted.
-    Table (BaseTable*, Bool countIt = True);
+    // Construct a Table object from a pointer to BaseTable.
+    // It is meant for internal Table objects, so the BaseTable is not counted.
+    // Thus the internal shared_ptr is null.
+    Table (BaseTable*);
+
+    // Construct a Table object from a shared pointer to BaseTable.
+    Table (const std::shared_ptr<BaseTable>&);
 
     // Open an existing table.
     void open (const String& name, const String& type, int tableOption,
@@ -1063,19 +1067,20 @@ protected:
 
 private:
     // Construct a BaseTable object from the table file.
-    static BaseTable* makeBaseTable (const String& name, const String& type,
-				     int tableOption,
-				     const TableLock& lockOptions,
-                                     const TSMOption& tsmOpt,
-				     Bool addToCache, uInt locknr);
-
+    static std::shared_ptr<BaseTable> makeBaseTable
+    (const String& name, const String& type, int tableOption,
+     const TableLock& lockOptions, const TSMOption& tsmOpt,
+     Bool addToCache, uInt locknr);
 
     // Get the pointer to the underlying BaseTable.
     // This is needed for some friend classes.
     BaseTable* baseTablePtr() const;
 
+    // Initialize the BaseTable pointers in this Table object.
+    void initBasePtr (BaseTable* ptr);
+
     // Look in the cache if the table is already open.
-    // If so, check if table option matches.
+    // If so, check if the table option matches.
     // If needed reopen the table for read/write and merge the lock options.
     BaseTable* lookCache (const String& name, int tableOption,
 			  const TableLock& tableInfo);
