@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #include <casacore/tables/Tables/TableColumn.h>
 #include <casacore/tables/Tables/Table.h>
@@ -124,7 +122,7 @@ const ColumnDesc& TableColumn::columnDesc() const
     { return baseColPtr_p->columnDesc(); }
 
 Table TableColumn::table() const
-    { return Table (baseTabPtr_p, False); }
+    { return Table (baseTabPtr_p); }
 
 
 Bool TableColumn::asBool (rownr_t rownr) const
