@@ -17,13 +17,11 @@
 //# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
 //#
 //# Correspondence concerning AIPS++ should be addressed as follows:
-//#        Internet email: aips2-request@nrao.edu.
+//#        Internet email: casa-feedback@nrao.edu.
 //#        Postal address: AIPS++ Project Office
 //#                        National Radio Astronomy Observatory
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
-//#
-//# $Id$
 
 #ifndef TABLES_TABLEDESC_H
 #define TABLES_TABLEDESC_H
@@ -244,6 +242,11 @@ public:
     // The destructor writes the table description if changed.
     ~TableDesc();
 
+    // Assignment is not supported, because it is impossible to define
+    // its semantics. Does the data need to be written into a file
+    // before being overwritten?
+    TableDesc& operator= (const TableDesc&) = delete;
+
     // Test if a description file exists (i.e. isReadable).
     static Bool isReadable (const String& tableDescName);
 
@@ -496,12 +499,6 @@ private:
     TDOption           option_p;        //# Table desc. open option
     AipsIO             iofil_p;         //# File
 
-    // Assignment is not supported, because it is impossible to define
-    // its semantics. Does the data need to be written into a file
-    // before being overwritten?
-    // Declaring it private, makes it unusable.
-    TableDesc& operator= (const TableDesc&);
-
     // Initialize the table description.
     void init (const TabPath&);
 
